@@ -5,9 +5,10 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     root.fill(&White)?;
 
     let mut chart = ChartBuilder::on(&root)
-        .x_label_area_size(25)
+        .x_label_area_size(35)
         .y_label_area_size(40)
-        .caption("Histogram Test", &("Arial", 50.0).into_font())
+        .margin(5)
+        .caption("Histogram Test", ("Arial", 50.0).into_font())
         .build_ranged(0u32..10u32, 0u32..10u32)?;
 
     chart
@@ -15,6 +16,9 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         .disable_x_mesh()
         .line_style_1(&White.mix(0.3))
         .x_label_offset(30)
+        .y_desc("Count")
+        .x_desc("Bucket")
+        .axis_desc_style(("Arial", 15).into_font())
         .draw()?;
 
     let data = [
