@@ -12,3 +12,8 @@ pub use bitmap::BitMapBackend;
 mod canvas;
 #[cfg(target_arch = "wasm32")]
 pub use canvas::CanvasBackend;
+
+#[cfg(test)]
+mod mocked;
+#[cfg(test)]
+pub use mocked::{create_mocked_drawing_area, MockedBackend};
