@@ -5,11 +5,9 @@
 <a href="https://crates.io/crates/plotters">
     <img style="display: inline!important" src="https://img.shields.io/crates/v/plotters.svg"></img>
 </a>
-
 <a href="https://docs.rs/plotters">
     <img style="display: inline!important" src="https://docs.rs/plotters/badge.svg"></img>
 </a>
-
 <a href="https://plumberserver.com/plotters-docs/plotters">
     <img style="display: inline! important" src="https://img.shields.io/badge/docs-development-lightgrey.svg"></img>
 </a>
@@ -74,7 +72,7 @@ Plotters is drawing library designed for rendering figures, plots, and charts, i
 To use Plotters, you can simply add Plotters into your `Cargo.toml`
 ```toml
 [depedencies]
-plotters = "^0.1.13"
+plotters = "^0.1.14"
 ```
 
 And the following code draws a quadratic function. `src/main.rs`,
@@ -85,7 +83,8 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let root = BitMapBackend::new("examples/outputs/0.png", (640, 480)).into_drawing_area();
     root.fill(&White)?;
     let mut chart = ChartBuilder::on(&root)
-        .caption("y=x^2", &("Arial", 50).into_font())
+        .caption("y=x^2", ("Arial", 50).into_font())
+        .margin(5)
         .x_label_area_size(30)
         .y_label_area_size(30)
         .build_ranged(-1f32..1f32, -0.1f32..1f32)?;
@@ -94,14 +93,62 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     chart.draw_series(LineSeries::new(
         (-50..=50).map(|x| x as f32 / 50.0).map(|x| (x, x * x)),
-        &RGBColor(255, 0, 0),
-    ))?;
+        &Red,
+    ))?
+        .label("y = x^2")
+        .legend(|(x,y)| Path::new(vec![(x,y), (x + 20,y)], &Red));
+
+    chart.configure_series_labels()
+        .background_style(&White.mix(0.8))
+        .border_style(&Black)
+        .draw()?;
+
     Ok(())
 }
 ```
 
 ![](https://raw.githubusercontent.com/38/plotters/master/examples/outputs/0.png)
 
+## Trying with Jupyter evcxr Kernel Interactively
+
+Plotters now supports integrate with `evcxr` and is able to interactively drawing plots in Jupyter Notebook.
+The feature `evcxr` should be enabled when including Plotters to Jupyter Notebook.
+
+The following code shows a minimal example of this.
+
+```text
+:dep plotters = { git = "https://github.com/38/plotters", default_features = false, features = ["evcxr"] }
+extern crate plotters;
+use plotters::prelude::*;
+
+let figure = evcxr_figure((640, 480), |root| {
+    root.fill(&White);
+    let mut chart = ChartBuilder::on(&root)
+        .caption("y=x^2", ("Arial", 50).into_font())
+        .margin(5)
+        .x_label_area_size(30)
+        .y_label_area_size(30)
+        .build_ranged(-1f32..1f32, -0.1f32..1f32)?;
+
+    chart.configure_mesh().draw()?;
+
+    chart.draw_series(LineSeries::new(
+        (-50..=50).map(|x| x as f32 / 50.0).map(|x| (x, x * x)),
+        &Red,
+    )).unwrap()
+        .label("y = x^2")
+        .legend(|(x,y)| Path::new(vec![(x,y), (x + 20,y)], &Red));
+
+    chart.configure_series_labels()
+        .background_style(&White.mix(0.8))
+        .border_style(&Black)
+        .draw()?;
+    Ok(())
+});
+figure
+```
+
+<img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/evcxr_animation.gif" width="450px"></img>
 
 ## Motivation of Plotting in Rust
 
@@ -192,6 +239,8 @@ You can also define your own element in the application code.
 
 You may also combine existing elements to build a complex element.
 
+To learn more about the element system, please read the [element module documentation](./element/index.html).
+
 ```rust
 use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
@@ -230,12 +279,11 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         0f32..1f32,
         (0..640, 0..480),
     ));
-    let font = ("Arial", 15.0).into_font();
 
     let dot_and_label = |x: f32, y: f32| {
         return EmptyElement::at((x, y))
             + Circle::new((0, 0), 3, ShapeStyle::from(&Black).filled())
-            + OwnedText::new(format!("({:.2},{:.2})", x, y), (10, 0), &font);
+            + Text::new(format!("({:.2},{:.2})", x, y), (10, 0), ("Arial", 15.0).into_font());
     };
 
     root.draw(&dot_and_label(0.5, 0.6))?;
@@ -261,11 +309,9 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     root.fill(&White);
     let root = root.margin(10, 10, 10, 10);
     // After this point, we should be able to draw construct a chart context
-    let font: FontDesc = ("Arial", 40.0).into();
-    // Create the chart object
     let mut chart = ChartBuilder::on(&root)
         // Set the caption of the chart
-        .caption("This is our first plot", &font)
+        .caption("This is our first plot", ("Arial",40).into_font())
         // Set the size of the label region
         .x_label_area_size(20)
         .y_label_area_size(40)
@@ -283,7 +329,6 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         .draw()?;
 
     // And we can draw something in the drawing area
-    let smaller_font = font.resize(10.0);
     chart.draw_series(LineSeries::new(
         vec![(0.0, 0.0), (5.0, 5.0), (8.0, 7.0)],
         &Red,
@@ -296,7 +341,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         &|c, s, st| {
             return EmptyElement::at(c)    // We want to construct a composed element on-the-fly
             + Circle::new((0,0),s,st.filled()) // At this point, the new pixel coordinate is established
-            + OwnedText::new(format!("{:?}", c), (10, 0), &smaller_font);
+            + Text::new(format!("{:?}", c), (10, 0), ("Arial", 10).into_font());
         },
     ))?;
     Ok(())
@@ -307,6 +352,8 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
 ## Misc
 
+### Development Version
+
 To use the latest development version, pull https://github.com/38/plotters.git. In `Cargo.toml`
 
 ```toml
@@ -314,6 +361,7 @@ To use the latest development version, pull https://github.com/38/plotters.git.
 plotters = { git = "https://github.com/38/plotters.git" }
 ```
 
+### Reducing Depending Libraries && Turning Off Backends
 Plotters now supports use features to control the backend dependencies. By default, `BitMapBackend` and `SVGBackend` are supported,
 use `default_features = false` in the dependency description in `Cargo.toml` and you can cherrypick the backend implementations.
 
@@ -355,6 +403,12 @@ pub mod element;
 pub mod series;
 pub mod style;
 
+#[cfg(feature = "evcxr")]
+pub mod evcxr;
+
+#[cfg(test)]
+pub use crate::drawing::create_mocked_drawing_area;
+
 /// The module imports the most commonly used types and modules in Plotters
 pub mod prelude {
     pub use crate::chart::{ChartBuilder, ChartContext};
@@ -369,13 +423,13 @@ pub mod prelude {
     pub use crate::drawing::*;
     pub use crate::series::{Histogram, LineSeries, PointSeries};
     pub use crate::style::{
-        Black, Blue, Color, Cyan, FontDesc, Green, HSLColor, IntoFont, Magenta, Mixable, Palette,
-        Palette100, Palette99, Palette9999, PaletteColor, RGBColor, Red, ShapeStyle, SimpleColor,
-        TextStyle, Transparent, White, Yellow,
+        Black, Blue, Color, Cyan, FontDesc, FontTransform, Green, HSLColor, IntoFont, Magenta,
+        Palette, Palette100, Palette99, Palette9999, PaletteColor, RGBColor, Red, ShapeStyle,
+        SimpleColor, TextStyle, Transparent, White, Yellow,
     };
 
     pub use crate::element::{
-        CandleStick, Circle, Cross, DynElement, EmptyElement, IntoDynElement, OwnedText, Path,
+        CandleStick, Circle, Cross, DynElement, EmptyElement, IntoDynElement, MultiLineText, Path,
         Pixel, Rectangle, Text,
     };
 
@@ -385,4 +439,7 @@ pub mod prelude {
     /// - `D`: The drawing backend type
     pub type DrawResult<T, D: DrawingBackend> =
         Result<T, crate::drawing::DrawingAreaErrorKind<D::ErrorType>>;
+
+    #[cfg(feature = "evcxr")]
+    pub use crate::evcxr::evcxr_figure;
 }
